#include "Button.h"

/**
 * @brief Button ctor
 * @param x distance from left side of screen
 * @param y distance from top of screen
 * @param w width
 * @param h height
 * @param key SDL key number
 * @param text Text to be displayed on the button
 * @param key_label Name of the key associated with the button
 */
Button::Button(unsigned x, unsigned y, unsigned w, unsigned h, unsigned key, std::string text, std::string key_label)
    : x(x), y(y), w(w), h(h), key(key), text(text), key_label(key_label) {
}

/**
 * @brief Check if a mouse click event happened on the button
 * @param mouse_x x position of the mouse click
 * @param mouse_y y position of the mouse click
 * @retval true the button was clicked
 * @retval false the button was not clicked
 */
bool Button::clicked(unsigned mouse_x, unsigned mouse_y) const {
    return x <= mouse_x && mouse_x <= x+w &&
           y <= mouse_y && mouse_y <= y+h;
}

/**
 * @brief Check if a key press toggled the button
 * @param key SDL code of key pressed
 * @retval true the button was activated
 * @retval false the button was not activated
 */
bool Button::pressed(unsigned key) const {
    return key == this->key;
}

/**
 * @brief Displays the button on the screen
 */
void Button::draw() const {
    /* Background */
    boxColor(sdlRenderer, x, y, x+w, y+h, 0x3494BAFF);
    /* Label */
    centeredtextColor(sdlRenderer, x+w/2, y+h/2, h*.75, text, 0x94E1FFFF);
    /* Shortcut key */
    centeredtextColor(sdlRenderer, x+h/4, y+h/4, h*.3, key_label, 0x94E1FFFF);
}
