#ifndef PIECE_H_INCLUDED
#define PIECE_H_INCLUDED

#include <vector>

#include "Block.h"
#include "TetrisWindow.h"

class Block;
class TetrisWindow;

/**
 * @class Piece
 * @author zsmb
 * @brief Base class for tetris pieces
 */
class Piece {
protected:
    std::vector<Block*> blocks;         //!< The 4 Blocks contained by the piece
    const TetrisWindow* window;         //!< The TetrisWindow the piece belongs to
    std::vector<char> rotation_numbers; //!< Numbers to be used when rotating the piece
    std::vector<char>& r;               //!< Shorthand for the above vector
    unsigned move_count;                //!< Number of times the piece has moved downward
    
private:
    bool is_clear(int x1, int y1, int x2, int y2, int x3, int y3) const;
    
public:
    Piece(const TetrisWindow* window);
    Piece(const TetrisWindow* window, const char numbers[]);
    virtual ~Piece();
    
    void draw() const;
    
    bool move(short direction);
    
    virtual void rotate();
    
    bool has_blocks() const;
    Block* get_block();
    
    unsigned get_move_count() const;
    
    bool is_clear_to_rotate(int& x, Block* pivot_block, int x1, int y1, int x2, int y2, int x3, int y3) const;
    
};

#endif // PIECE_H_INCLUDED
